@@ -1,10 +1,8 @@
 package ThirdTestApp;
 
-BEGIN
-{
+BEGIN {
     my $moodel = $ENV{WHICH_MOODEL} || "Moo";
-    eval "use $moodel;";
-    $@ and die $@;
+    eval "use $moodel;"; $@ and die $@;
     $moodel->import;
 }
 use MooX::Cmd execute_from_new => undef;
